==> haskell-asn1-parse-0.9.4-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-7rtS1fISBIfCeVTC9dBl5O
key: asn1-parse-0.9.4-7rtS1fISBIfCeVTC9dBl5O
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 56cb0084f7025bcb6a164d38b79fdfea
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-7rtS1fISBIfCeVTC9dBl5O
depends:
    asn1-encoding-0.9.5-CVAJwfXBBy32v2S991bpT7
    asn1-types-0.3.2-KLmYgaafoKXEmGB31FMlKz base-4.11.1.0
    bytestring-0.10.8.2
abi-depends: asn1-encoding-0.9.5-CVAJwfXBBy32v2S991bpT7=85b5a949c9e94818387138acf6fa1bce
             asn1-types-0.3.2-KLmYgaafoKXEmGB31FMlKz=50cb2ffa2f744a3e0846b2c42242d6d1
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.4-73-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-Ck3jh4yY1wj4Geg3XZ2hTY
key: asn1-parse-0.9.4-Ck3jh4yY1wj4Geg3XZ2hTY
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 38ad2e61acb599f16fce15dc42222b13
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-Ck3jh4yY1wj4Geg3XZ2hTY
depends:
    asn1-encoding-0.9.5-D6wKH3oeWgmIGlgRzG9HDX
    asn1-types-0.3.2-APLQoNROQGmB0wmh7tzA2H base-4.11.1.0
    bytestring-0.10.8.2
abi-depends: asn1-encoding-0.9.5-D6wKH3oeWgmIGlgRzG9HDX=1126404f31e4ae6f8da3d47fe6a6b433
             asn1-types-0.3.2-APLQoNROQGmB0wmh7tzA2H=02576d862bb6ac63ddf066c176cc45e8
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
